"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDbIcons = void 0;
const promises_1 = require("node:fs/promises");
const fs_1 = require("./../../dependencies/fs/index.js");
const _specs_1 = require("./../../specs/technos.js");
const get_package_json_data_js_1 = require("../package/get-package-json-data.js");
const prisma_generate_regex_js_1 = require("../regex/prisma-generate.regex.js");
const prisma_provider_regex_js_1 = require("../regex/prisma-provider.regex.js");
const getDbIcons = async (path) => {
    const packageJsonExists = await (0, fs_1.fileExists)(`${path}/package.json`);
    if (!packageJsonExists) {
        return [];
    }
    const packageJson = await (0, get_package_json_data_js_1.getPackageJsonData)(path);
    if (!packageJson.dependencies.includes('prisma')) {
        return [];
    }
    const scripts = Object.values(packageJson.scripts);
    const prismaConfigFiles = scripts.reduce((result, command) => {
        const matches = command.match(prisma_generate_regex_js_1.prismaGenerateRegex);
        if (matches && matches.length === 4) {
            const prismaConfigPath = `${path}/${matches[3] ? matches[3] : 'prisma/schema.prisma'}`;
            return [...result, prismaConfigPath];
        }
        return result;
    }, []);
    const prismaConfigFilesContent = await Promise.all(prismaConfigFiles.map((path) => (0, promises_1.readFile)(path, 'utf-8')));
    return prismaConfigFilesContent.reduce((result, fileContent) => {
        const matches = fileContent.match(prisma_provider_regex_js_1.prismaProviderRegex);
        if (!matches) {
            return result;
        }
        const techno = _specs_1.technosSpecs[matches[1]];
        if (result.some((el) => el.iconUrl === techno.iconUrl)) {
            return result;
        }
        return [...result, techno];
    }, []);
};
exports.getDbIcons = getDbIcons;
//# sourceMappingURL=get-db-icons.js.map