import { readFile } from 'node:fs/promises';
import { fileExists } from './../../dependencies/fs/index.js';
import { technosSpecs } from './../../specs/technos.js';
import { getPackageJsonData } from '../package/get-package-json-data.js';
import { prismaGenerateRegex } from '../regex/prisma-generate.regex.js';
import { prismaProviderRegex } from '../regex/prisma-provider.regex.js';
export const getDbIcons = async (path) => {
    const packageJsonExists = await fileExists(`${path}/package.json`);
    if (!packageJsonExists) {
        return [];
    }
    const packageJson = await getPackageJsonData(path);
    if (!packageJson.dependencies.includes('prisma')) {
        return [];
    }
    const scripts = Object.values(packageJson.scripts);
    const prismaConfigFiles = scripts.reduce((result, command) => {
        const matches = command.match(prismaGenerateRegex);
        if (matches && matches.length === 4) {
            const prismaConfigPath = `${path}/${matches[3] ? matches[3] : 'prisma/schema.prisma'}`;
            return [...result, prismaConfigPath];
        }
        return result;
    }, []);
    const prismaConfigFilesContent = await Promise.all(prismaConfigFiles.map((path) => readFile(path, 'utf-8')));
    return prismaConfigFilesContent.reduce((result, fileContent) => {
        const matches = fileContent.match(prismaProviderRegex);
        if (!matches) {
            return result;
        }
        const techno = technosSpecs[matches[1]];
        if (result.some((el) => el.iconUrl === techno.iconUrl)) {
            return result;
        }
        return [...result, techno];
    }, []);
};
//# sourceMappingURL=get-db-icons.js.map